# DtoPaginationRespDtoInjectionItem


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**items** | [**List[DtoInjectionItem]**](DtoInjectionItem.md) |  | [optional] 
**total** | **int** |  | [optional] 
**total_pages** | **int** |  | [optional] 

## Example

```python
from rcabench.openapi.models.dto_pagination_resp_dto_injection_item import DtoPaginationRespDtoInjectionItem

# TODO update the JSON string below
json = "{}"
# create an instance of DtoPaginationRespDtoInjectionItem from a JSON string
dto_pagination_resp_dto_injection_item_instance = DtoPaginationRespDtoInjectionItem.from_json(json)
# print the JSON string representation of the object
print(DtoPaginationRespDtoInjectionItem.to_json())

# convert the object into a dict
dto_pagination_resp_dto_injection_item_dict = dto_pagination_resp_dto_injection_item_instance.to_dict()
# create an instance of DtoPaginationRespDtoInjectionItem from a dict
dto_pagination_resp_dto_injection_item_from_dict = DtoPaginationRespDtoInjectionItem.from_dict(dto_pagination_resp_dto_injection_item_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


